@@ -5,5 +5,5 @@ import pathlib
 import pickle
 
 def get_dict() -> dict:
-    with open('dict_pkl', 'rb') as pickle_dict:
+    with open('dict.pkl', 'rb') as pickle_dict:
         return pickle.load(pickle_dict)
\ No newline at end of file
